# 大杂烩

```{toctree}
eagerpy/index
```

## 课程

- [中科院实景课堂](https://v.ucas.ac.cn/main/index.do?menuCode=1)
- [中国科学院大学UCAS计算机视觉课程2022春](https://space.bilibili.com/358222222/channel/collectiondetail?sid=505219)

## 资源

- [transformers](https://github.com/huggingface/transformers)
- [deap: 遗传算法](https://github.com/deap/deap)
